@@ -74,9 +74,10 @@ class XsnippetExtension(nautilus.MenuProvider):
         """
 
         language = "Autodetection"
-        title, ext = os.path.splitext(filename)
-        if XsnippetExtension.languages.has_key(ext):
-            language = XsnippetExtension.languages[ext]
+        title = os.path.basename(filename)
+        extension = os.path.splitext(filename)[1]
+        if XsnippetExtension.languages.has_key(extension):
+            language = XsnippetExtension.languages[extension]
 
         data = {
             "title" : title,
